@@ -1,5 +1,6 @@
-#' @importFrom rlang sym
-#'
+
+#' @export
+dplyr::`%>%`
 
 case_id_ <- function(eventlog) sym(case_id(eventlog))
 activity_id_ <- function(eventlog) sym(activity_id(eventlog))
@@ -35,6 +36,15 @@ if_start <- function(node, true, false) {
 	ifelse(node %in% c("ARTIFICIAL_START"), true, false)
 }
 
+# Return a plotly instead of ggplot2 if plotly == TRUE
+return_plotly <- function(p, plotly) {
+	if (plotly) {
+		return(ggplotly(p))
+	} else {
+		return(p)
+	}
+}
+
 # Warning: The `eventlog` argument of `func()` is deprecated as of processmapR 0.4.0.
 # Please use the `log` argument instead.
 # WARNING: Works only on exported functions!
@@ -51,3 +61,20 @@ lifecycle_warning_eventlog <- function (log, eventlog = deprecated()) {
 
 	return(log)
 }
+
+# Warning: The `.abbreviate` argument of `func()` is deprecated as of processmapR 0.5.2.
+# Please use the `abbreviate` argument instead.
+# WARNING: Works only on exported functions!
+lifecycle_warning_abbreviate <- function (abbreviate, .abbreviate = deprecated()) {
+
+	cl <- sys.call(-1L)
+	func <- get(as.character(cl[[1L]]), mode = "function", envir = sys.frame(-2L))
+	func_name <- match.call(definition = func, call = cl)[[1L]]
+
+	if(lifecycle::is_present(.abbreviate)) {
+		lifecycle::deprecate_warn("0.5.2", paste0(func_name, "(.abbreviate)"), paste0(func_name, "(abbreviate)"))
+		return(.abbreviate)
+	}
+
+	return(abbreviate)
+}
